@@ -1,17 +1,12 @@
 print.data.list <-
 function(x, ...){
 	
-	# simpler to work with x as a 
-	# list rather than a data frame
-	# for some computations
-	xl <- unclass(x)
-	
 	# print each variable in x
 	for(i in seq_along(x)){
 		
 		# get information about the variable
 		subsetdim <- attr(x[[i]],"subsetdim")
-		attr(xl[[i]],"subsetdim") <- NULL
+		attr(x[[i]],"subsetdim") <- NULL
 		varname <- varnames(x)[i]	# could be out of the loop?
 		
 		if(is.null(varname)) varname <- i
